# Code

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**type** | **str** |  | 
**description** | **str** |  | [optional] 
**code_range** | **str** |  | 
**match_column_name** | **str** |  | 
**match_column_value** | **str** |  | 
**extract_column** | **str** |  | [optional] 
**hierarchy_level** | **float** |  | 
**parent_code_id** | **str** |  | [optional] 
**parent_code** | [**Code**](Code.md) |  | [optional] 
**children_codes** | [**list[Code]**](Code.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

